aboutsummaryrefslogtreecommitdiff
path: root/obj_tag.go
diff options
context:
space:
mode:
Diffstat (limited to 'obj_tag.go')
-rw-r--r--obj_tag.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/obj_tag.go b/obj_tag.go
index 9230274d..440eb15e 100644
--- a/obj_tag.go
+++ b/obj_tag.go
@@ -10,14 +10,14 @@ import (
type Tag struct {
Hash Hash
Target Hash
- TargetType ObjType
+ TargetType ObjectType
Name []byte
Tagger *Ident
Message []byte
}
-// ObjType allows Tag to satisfy the Object interface.
-func (*Tag) ObjType() ObjType {
+// ObjectType allows Tag to satisfy the Object interface.
+func (*Tag) ObjectType() ObjectType {
return ObjTag
}